This function compares the installed version of the rfishbase package with the latest version available on CRAN. It prints a message if the installed version is outdated.

check_rfishbase_version()

Examples

check_rfishbase_version()
#> rfishbase is out of date.
#>   Installed: 5.0.2
#>   CRAN: 5.0.3