The resultant trait names are the snake-case names that are used in FishLife and are preceded by log( to indicate that the traits are in log space.

translate_trait_names(trait)

Arguments

trait

A character vector of trait names from FishBase.

Value

A character vector of trait names in snake_case format rather than the format found in FishBase, which is often shorted versions of the trait names.

Examples

translate_trait_names("Loo")
#> [1] "log(length_infinity)"
translate_trait_names("K")
#> [1] "log(growth_coefficient)"
translate_trait_names(c("Loo", "K", "M"))
#> [1] "log(length_infinity)"    "log(growth_coefficient)"
#> [3] "log(natural_mortality)"