TODO: Provide more details on the parameter.
make_growth_coefficient_prior(data, type = c("informative", "diffuse"))
Arguments
- data
A data frame for a single species because you might
need more than one trait to create a prior.
- type
A character string indicating the type of prior. The default
is "informative".