R/make_mortality_.R
make_informative_mortality_prior.RdThe Hamel–Cope prior for natural mortality is thought to be a good, informative prior for natural mortality. It is based on the maximum age of a fish species.
make_informative_mortality_prior(log_maximum_age)An informative lognormal distribution is returned using the prior class.
The Hamel–Cope prior is based on the assumption that natural mortality follows a lognormal distribution. The mean of the lognormal distribution is calculated as 5.40 divided by the maximum age of the fish species. The standard deviation of the lognormal distribution is set to 0.31.