Make a prior for natural mortality using either an informative or diffuse prior. The informative prior is based on the Hamel–Cope prior, which is based on the maximum age of a fish species. The diffuse prior is based on the estimated natural mortality of a fish species.
make_mortality_prior(data, type = c("diffuse", "informative"))A data frame returned by summarize_fishbase_traits() containing
life-history information for at least one fish species.
A character string indicating the type of prior to be created.
Either "diffuse" or "informative". The default is "diffuse".
A tibble is returned that contains three columns, "name" from the input
data frame with the species name, "parameter" specifying which parameter
the prior is for, and "prior" that contains the S4 class prior.